@@ -119,6 +119,20 @@ string AttrType_to_String(const AttrType at)
         return "Url";
     case Attr_other_xml:
         return "OtherXML";
+    //
+    // Added for DAP4
+    case Attr_int8:
+        return "Int8";
+    case Attr_uint8:
+        return "UInt8";
+    case Attr_int64:
+        return "Int64";
+    case Attr_uint64:
+        return "UInt64";
+    case Attr_enum:
+        return "Enumeration";
+    case Attr_opaque:
+        return "Opaque";
     default:
         return "";
     }
@@ -151,6 +165,20 @@ AttrType String_to_AttrType(const string &s)
         return Attr_url;
     else if (s2 == "otherxml")
         return Attr_other_xml;
+    //
+    // Added for DAP4
+    else if (s2 == "int8")
+        return Attr_int8;
+    else if (s2 == "uint8")
+        return Attr_uint8;
+    else if (s2 == "int64")
+        return Attr_int64;
+    else if (s2 == "uint64")
+        return Attr_uint64;
+    else if (s2 == "enumeration")
+        return Attr_enum;
+    else if (s2 == "opaque")
+        return Attr_opaque;
     else
         return Attr_unknown;
 }
@@ -397,6 +425,122 @@ unsigned int AttrTable::append_attr(const string &name, const string &type, vect
     }
 }
 
+/** If the given name already refers to an attribute, and the attribute has a
+ value, the given value is appended to the attribute vector. Calling this
+ function repeatedly is the way to append to an attribute vector.
+
+ The function throws an Error if the attribute is a container,
+ or if the type of the input value does not match the existing attribute's
+ type. Use <tt>append_container()</tt> to add container attributes.
+
+ This method performs a simple search for <tt>name</tt> in this attribute
+ table only; sub-tables are not searched and the dot notation is not
+ recognized.
+
+ @brief Add an attribute to the table.
+ @return Returns the length of the added attribute value.
+ @param name The name of the attribute to add or modify.
+ @param type The type of the attribute to add or modify.
+ @param value The value to add to the attribute table. 
+ @param is_utf8_str The flag to indicate if this is a utf8 string. */
+unsigned int AttrTable::append_attr(const string &name, const string &type, const string &value, bool is_utf8_str)
+{
+    DBG(cerr << "Entering AttrTable::append_attr" << endl);
+#if WWW_ENCODING
+    string lname = www2id(name);
+#else
+    string lname = remove_space_encoding(name);
+#endif
+
+    Attr_iter iter = simple_find(lname);
+
+    // If the types don't match OR this attribute is a container, calling
+    // this mfunc is an error!
+    if (iter != attr_map.end() && ((*iter)->type != String_to_AttrType(type)))
+        throw Error(string("An attribute called `") + name + string("' already exists but is of a different type"));
+    if (iter != attr_map.end() && (get_type(iter) == "Container"))
+        throw Error(string("An attribute called `") + name + string("' already exists but is a container."));
+
+    if (iter != attr_map.end()) { // Must be a new attribute value; add it.
+        (*iter)->attr->push_back(value);
+        (*iter)->is_utf8_str = is_utf8_str;
+        return (*iter)->attr->size();
+    }
+    else { // Must be a completely new attribute; add it
+        entry *e = new entry;
+
+        e->name = lname;
+        e->is_alias = false;
+        e->type = String_to_AttrType(type); // Record type using standard names.
+        e->is_utf8_str = is_utf8_str;
+        e->attr = new vector<string> ;
+        e->attr->push_back(value);
+
+        attr_map.push_back(e);
+
+        return e->attr->size(); // return the length of the attr vector
+    }
+}
+
+/** This version of append_attr() takes a vector<string> of values.
+ If the given name already refers to an attribute, and the attribute has
+ values, append the new values to the existing ones.
+
+ The function throws an Error if the attribute is a container,
+ or if the type of the input value does not match the existing attribute's
+ type. Use <tt>append_container()</tt> to add container attributes.
+
+ This method performs a simple search for <tt>name</tt> in this attribute
+ table only; sub-tables are not searched and the dot notation is not
+ recognized.
+
+ @brief Add an attribute to the table.
+ @return Returns the length of the added attribute value.
+ @param name The name of the attribute to add or modify.
+ @param type The type of the attribute to add or modify.
+ @param values A vector of values. Note: The vector is COPIED, not stored. 
+ @param is_utf8_str The flag to indicate if this is a utf8 string. */
+
+unsigned int AttrTable::append_attr(const string &name, const string &type, vector<string> *values, bool is_utf8_str)
+{
+    DBG(cerr << "Entering AttrTable::append_attr(..., vector)" << endl);
+#if WWW_ENCODING
+    string lname = www2id(name);
+#else
+    string lname = remove_space_encoding(name);
+#endif
+    Attr_iter iter = simple_find(lname);
+
+    // If the types don't match OR this attribute is a container, calling
+    // this mfunc is an error!
+    if (iter != attr_map.end() && ((*iter)->type != String_to_AttrType(type)))
+        throw Error(string("An attribute called `") + name + string("' already exists but is of a different type"));
+    if (iter != attr_map.end() && (get_type(iter) == "Container"))
+        throw Error(string("An attribute called `") + name + string("' already exists but is a container."));
+
+    if (iter != attr_map.end()) { // Must be new attribute values; add.
+        vector<string>::iterator i = values->begin();
+        while (i != values->end())
+            (*iter)->attr->push_back(*i++);
+         (*iter)->is_utf8_str = is_utf8_str;
+        return (*iter)->attr->size();
+    }
+    else { // Must be a completely new attribute; add it
+        entry *e = new entry;
+
+        e->name = lname;
+        e->is_alias = false;
+        e->type = String_to_AttrType(type); // Record type using standard names.
+        e->is_utf8_str = is_utf8_str;
+        e->attr = new vector<string> (*values);
+
+        attr_map.push_back(e);
+
+        return e->attr->size(); // return the length of the attr vector
+    }
+}
+
+
 /** Create and append an attribute container to this AttrTable. If this
  attribute table already contains an attribute container called
  <tt>name</tt> an exception is thrown. Return a pointer to the new container.
@@ -1030,6 +1174,28 @@ bool AttrTable::attr_alias(const string &alias, const string &name)
     return attr_alias(alias, this, name);
 }
 
+
+/**
+ * Checks the child Attributes for ones with dap4 types and, when found, adds a description of each to the inventory
+ * @param path
+ * @param inventory
+ * @return true when dap4 types are found, false otherwise.
+ */
+bool AttrTable::has_dap4_types(const std::string &path, std::vector<std::string> &inventory) const
+{
+    bool has_d4_attr = false;
+    for(auto attr:attr_map){
+        string attr_fqn = path + "@" + attr->name;
+        bool isa_d4_attr = attr->is_dap4_type(attr_fqn, inventory);
+        if(isa_d4_attr){
+            inventory.emplace_back(AttrType_to_String(attr->type) + " " + attr_fqn);
+        }
+        has_d4_attr |= isa_d4_attr;
+    }
+    return has_d4_attr;
+}
+
+
 /** Erase the entire attribute table. This returns an AttrTable to the empty
  state that's the same as the object generated by the null constructor.
  @brief Erase the attribute table. */
@@ -1058,12 +1224,21 @@ const string double_quote = "\"";
 // those quotes were added by the handlers as a hack to get the output
 // formatting correct for the DAS. jhrg 7/30/08
 
-static void write_string_attribute_for_das(ostream &out, const string &value, const string &term)
+static void write_string_attribute_for_das(ostream &out, const string &value, const string &term, bool is_utf8_str)
 {
-    if (is_quoted(value))
-        out << value << term;
+
+    string esc_value = is_utf8_str?value:escattr(value);
+#if 0
+    string esc_value = escattr(value);
+#endif
+
+    // The value is already escaped so the following check is not necessary. KY 2022-08-22
+#if 0
+    if (is_quoted(esc_value))
+        out << esc_value << term;
     else
-        out << double_quote << value << double_quote << term;
+#endif
+    out << double_quote << esc_value << double_quote << term;
 }
 
 #if 0
@@ -1190,11 +1365,25 @@ void AttrTable::simple_print(ostream &out, string pad, Attr_iter i, bool derefer
         out << pad << get_type(i) << " " << add_space_encoding(get_name(i)) << " ";
 #endif
         vector<string> *sxp = (*i)->attr;
+
         vector<string>::iterator last = sxp->end() - 1;
-        for (vector<string>::iterator i = sxp->begin(); i != last; ++i) {
-            write_string_attribute_for_das(out, *i, ", ");
+        for (vector<string>::iterator i_s = sxp->begin(); i_s != last; ++i_s) {
+            write_string_attribute_for_das(out, *i_s, ", ",(*i)->is_utf8_str);
         }
-        write_string_attribute_for_das(out, *last, ";\n");
+        write_string_attribute_for_das(out, *last, ";\n",(*i)->is_utf8_str);
+
+        // The following code is intended to replace the code above. 
+        // However, it causes the obscure test failure at HDF5 handler's t_big_str.h5 DAS test.
+        // it also causes the 17th etc NcML tests failed.
+        // Leave here and may check this later. KY 2022-09-22
+#if 0
+        for (const auto &attr:(*sxp)) {
+            if (attr != (*sxp).back())  
+                write_string_attribute_for_das(out, attr, ", ",(*i)->is_utf8_str);
+            else 
+                write_string_attribute_for_das(out, attr, ";\n",(*i)->is_utf8_str);
+        }
+#endif
     }
         break;
 
@@ -1471,6 +1660,22 @@ void AttrTable::print_xml_writer(XMLWriter &xml)
                 if (xmlTextWriterWriteRaw(xml.get_writer(), (const xmlChar*) get_attr(i, 0).c_str()) < 0)
                     throw InternalErr(__FILE__, __LINE__, "Could not write OtherXML value");
             }
+            // Need to escape special characters that xml doesn't allow. Note: the XML escaping is
+            // not the same as the das string escaping. See escattr_xml in the escaping.cc for details.
+            // KY 08-22-22
+            else if (get_attr_type(i) == Attr_string || get_attr_type(i) == Attr_url) {
+                for (unsigned j = 0; j < get_attr_num(i); ++j) {
+                    if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "value") < 0)
+                        throw InternalErr(__FILE__, __LINE__, "Could not write value element");
+
+                    string s = ((*i)->is_utf8_str)?get_attr(i,j):escattr_xml(get_attr(i,j));
+                    if (xmlTextWriterWriteString(xml.get_writer(), (const xmlChar*) s.c_str()) < 0)
+                        throw InternalErr(__FILE__, __LINE__, "Could not write attribute value");
+
+                    if (xmlTextWriterEndElement(xml.get_writer()) < 0)
+                        throw InternalErr(__FILE__, __LINE__, "Could not end value element");
+                }
+            }
             else {
                 for (unsigned j = 0; j < get_attr_num(i); ++j) {
                     if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "value") < 0)
