@@ -31,6 +31,7 @@
 
 #include "config.h"
 
+#include <cstdint>
 #include <string>
 #include <sstream>
 #include <algorithm>
@@ -162,6 +163,7 @@ Constructor::set_read_p(bool state)
 
     @param constrained If true, return the size after applying a constraint.
     @return  The number of bytes used by the variable.
+    @deprecated Use width_ll()
  */
 unsigned int
 Constructor::width(bool constrained) const
@@ -181,6 +183,29 @@ Constructor::width(bool constrained) const
     return sz;
 }
 
+/**
+ * @brief Get the width of the Constructor's fields
+ * @param constrained If true, return the constrained size
+ * @return The number of bytes needed to store the values of this instance
+ */
+int64_t
+Constructor::width_ll(bool constrained) const
+{
+    int64_t sz = 0;
+
+    for (auto var: d_vars) {
+        if (constrained) {
+            if (var->send_p())
+                sz += var->width_ll(constrained);
+        }
+        else {
+            sz += var->width_ll(constrained);
+        }
+    }
+
+    return sz;
+}
+
 BaseType *
 Constructor::var(const string &name, bool exact_match, btp_stack *s)
 {
@@ -315,6 +340,33 @@ Constructor::get_var_index(int i)
     return *(d_vars.begin() + i);
 }
 
+/**
+ * @brief Set the ith element of d_vars to a variable object.
+ * @note  This method only sets the ith element to a BaseType object. 
+ * The user should be responsible to release or allocate the resource properly.
+ * Use this method cautionally. 
+ * @param bt A pointer to the variable that is assigned to the ith element.
+ * @param i The index of the variable to be set.
+ */
+
+void Constructor::set_var_index(BaseType *bt,int i) {
+
+    if (!bt)
+        throw InternalErr(__FILE__, __LINE__, "The BaseType parameter cannot be null.");
+
+    if (i<0 || i>= (int)(d_vars.size())) 
+        throw InternalErr(__FILE__, __LINE__, "The index must be within the variable vector  range..");
+
+    bt->set_parent(this);
+
+    // Update the is_dap4 property
+    if (bt->is_dap4())
+        set_is_dap4(true);
+
+    d_vars[i] = bt;
+
+}
+
 /** Adds an element to a Constructor.
 
     @param bt A pointer to the variable to add to this Constructor.
@@ -332,9 +384,7 @@ Constructor::add_var(BaseType *bt, Part)
     // he/she wishes. The policy is: "If it is allocated outside, it is
     // deallocated outside, if it is allocated inside, it is deallocated
     // inside"
-    BaseType *btp = bt->ptr_duplicate();
-    btp->set_parent(this);
-    d_vars.push_back(btp);
+    add_var_nocopy(bt->ptr_duplicate());
 }
 
 /** Adds an element to a Constructor.
@@ -349,6 +399,10 @@ Constructor::add_var_nocopy(BaseType *bt, Part)
 
     bt->set_parent(this);
     d_vars.push_back(bt);
+
+    // Update the is_dap4 property
+    if (bt->is_dap4())
+        set_is_dap4(true);
 }
 
 /**
@@ -407,6 +461,9 @@ bool Constructor::read()
 void
 Constructor::intern_data(ConstraintEvaluator & eval, DDS & dds)
 {
+    if (is_dap4())
+        throw Error(string("A method usable only with DAP2 variables was called on a DAP4 variable (").append(name()).append(")."), __FILE__, __LINE__);
+
     if (!read_p())
         read();          // read() throws Error and InternalErr
 
@@ -467,6 +524,9 @@ Constructor::compute_checksum(Crc32 &)
 void
 Constructor::intern_data()
 {
+    if (!read_p())
+        read();  // read() throws Error
+
     for (auto var: d_vars) {
         if (var->send_p()) {
             var->intern_data(/*checksum, dmr, eval*/);
@@ -517,8 +577,7 @@ Constructor::deserialize(D4StreamUnMarshaller &um, DMR &dmr)
 }
 
 void
-Constructor::print_decl(FILE *out, string space, bool print_semi,
-                        bool constraint_info, bool constrained)
+Constructor::print_decl(FILE *out, string space, bool print_semi, bool constraint_info, bool constrained)
 {
     ostringstream oss;
     print_decl(oss, space, print_semi, constraint_info, constrained);
@@ -526,8 +585,7 @@ Constructor::print_decl(FILE *out, string space, bool print_semi,
 }
 
 void
-Constructor::print_decl(ostream &out, string space, bool print_semi,
-                        bool constraint_info, bool constrained)
+Constructor::print_decl(ostream &out, string space, bool print_semi, bool constraint_info, bool constrained)
 {
     if (constrained && !send_p())
         return;
@@ -755,6 +813,26 @@ Constructor::make_dropped_vars_attr_table(vector<BaseType *> *dropped_vars)
     return dv_table;
 }
 
+
+/**
+ * When send_p() is true and the attributes or variables contain dap4 data types then
+ *   a description of the instance is added to the inventory and true is returned.
+ * @param inventory is a value-result parameter
+ * @return True when send_p() is true and this object contains dap4 types variables or attributes, false otherwise
+ */
+bool Constructor::is_dap4_projected(std::vector<std::string> &inventory)
+{
+    bool has_projected_dap4 = false;
+    if(send_p()) {
+        has_projected_dap4 = attributes()->has_dap4_types(FQN(),inventory);
+        for (const auto var: variables()) {
+            has_projected_dap4 |= var->is_dap4_projected(inventory);
+        }
+    }
+    return has_projected_dap4;
+}
+
+
 /** @brief dumps information about this object
  *
  * Displays the pointer value of this instance and information about this
