@@ -658,21 +658,21 @@ D4Enum::ops(BaseType *b, int op)
         case dods_int8_c:
             return Cmp<dods_int64, dods_int8>(op, d_buf, static_cast<Int8*>(b)->value());
         case dods_byte_c:
-            return SUCmp<dods_int64, dods_byte>(op, d_buf, static_cast<Byte*>(b)->value());
+            return Cmp<dods_int64, dods_byte>(op, d_buf, static_cast<Byte*>(b)->value());
         case dods_int16_c:
             return Cmp<dods_int64, dods_int16>(op, d_buf, static_cast<Int16*>(b)->value());
         case dods_uint16_c:
-            return SUCmp<dods_int64, dods_uint16>(op, d_buf, static_cast<UInt16*>(b)->value());
+            return Cmp<dods_int64, dods_uint16>(op, d_buf, static_cast<UInt16*>(b)->value());
         case dods_int32_c:
             return Cmp<dods_int64, dods_int32>(op, d_buf, static_cast<Int32*>(b)->value());
         case dods_uint32_c:
-            return SUCmp<dods_int64, dods_uint32>(op, d_buf, static_cast<UInt32*>(b)->value());
+            return Cmp<dods_int64, dods_uint32>(op, d_buf, static_cast<UInt32*>(b)->value());
 #if 0
             // FIXME
         case dods_int64_c:
             return Cmp<dods_int64, dods_int64>(op, d_buf, static_cast<D4Enum*>(b)->value());
         case dods_uint64_c:
-            return SUCmp<dods_int64, dods_uint64>(op, d_buf, static_cast<D4Enum*>(b)->value());
+            return Cmp<dods_int64, dods_uint64>(op, d_buf, static_cast<D4Enum*>(b)->value());
 #endif
         case dods_float32_c:
             return Cmp<dods_int64, dods_float32>(op, d_buf, static_cast<Float32*>(b)->value());
