@@ -54,7 +54,13 @@
 #include <cstdlib>
 #include <cstring>
 
+#ifdef HAVE_UUID_UUID_H
 #include <uuid/uuid.h>	// used to build CID header value for data ddx
+#elif defined(HAVE_UUID_H)
+#include <uuid.h>
+#else
+#error "Could not find UUID library header"
+#endif
 
 #include <GetOpt.h>
 
@@ -262,7 +268,7 @@ DODSFilter::process_options(int argc, char *argv[])
     int option_char;
     GetOpt getopt (argc, argv, "ce: v: d: f: r: l: o: u: t: ");
 
-    while ((option_char = getopt()) != EOF) {
+    while ((option_char = getopt()) != -1) {
         switch (option_char) {
         case 'c': d_comp = true; break;
         case 'e': set_ce(getopt.optarg); break;
@@ -895,12 +901,12 @@ DODSFilter::dataset_constraint_ddx(DDS & dds, ConstraintEvaluator & eval,
     uuid_t uu;
     uuid_generate(uu);
     char uuid[37];
-    uuid_unparse(uu, &uuid[0]);
+    uuid_unparse(uu, uuid);
     char domain[256];
     if (getdomainname(domain, 255) != 0 || strlen(domain) == 0)
 	strncpy(domain, "opendap.org", 255);
 
-    string cid = string(&uuid[0]) + "@" + string(&domain[0]);
+    string cid = string(uuid) + "@" + string(domain);
 
     // Send constrained DDX with a data blob reference
     dds.print_xml_writer(out, true, cid);
