@@ -77,33 +77,42 @@ public:
 
     virtual ~Int32();
 
-    virtual BaseType *ptr_duplicate();
-    virtual unsigned int width(bool constrained = false) const;
+    BaseType *ptr_duplicate() override;
+
+    unsigned int width(bool = false) const override
+    {
+        return sizeof(dods_int32);
+    }
+
+    int64_t width_ll(bool = false) const override
+    {
+        return sizeof(dods_int32);
+    }
 
     //DAP2
-    virtual bool serialize(ConstraintEvaluator &eval, DDS &dds, Marshaller &m, bool ce_eval = true);
-    virtual bool deserialize(UnMarshaller &um, DDS *dds, bool reuse = false);
+    bool serialize(ConstraintEvaluator &eval, DDS &dds, Marshaller &m, bool ce_eval = true) override;
+    bool deserialize(UnMarshaller &um, DDS *dds, bool reuse = false) override;
 
     // DAP4
-    virtual void compute_checksum(Crc32 &checksum);
-    virtual void serialize(D4StreamMarshaller &m, DMR &dmr, /*ConstraintEvaluator &eval,*/ bool filter = false);
-    virtual void deserialize(D4StreamUnMarshaller &um, DMR &dmr);
+    void compute_checksum(Crc32 &checksum) override;
+    void serialize(D4StreamMarshaller &m, DMR &dmr, /*ConstraintEvaluator &eval,*/ bool filter = false) override;
+    void deserialize(D4StreamUnMarshaller &um, DMR &dmr) override;
 
-    virtual unsigned int val2buf(void *val, bool reuse = false);
-    virtual unsigned int buf2val(void **val);
+    unsigned int val2buf(void *val, bool reuse = false) override;
+    unsigned int buf2val(void **val) override;
 
     virtual bool set_value(dods_int32 i);
     virtual dods_int32 value() const;
 
-    virtual void print_val(FILE *out, string space = "",
-                           bool print_decl_p = true);
-    virtual void print_val(ostream &out, string space = "",
-                           bool print_decl_p = true);
+    void print_val(FILE *out, string space = "",
+                           bool print_decl_p = true) override;
+    void print_val(ostream &out, string space = "",
+                           bool print_decl_p = true) override;
 
-    virtual bool ops(BaseType *b, int op);
-    virtual bool d4_ops(BaseType *b, int op);
+    bool ops(BaseType *b, int op) override;
+    bool d4_ops(BaseType *b, int op) override;
 
-    virtual void dump(ostream &strm) const ;
+    void dump(ostream &strm) const  override;
 };
 
 } // namespace libdap
