@@ -48,13 +48,13 @@ class UnMarshaller;
 
 class Int64: public BaseType
 {
-    virtual unsigned int val2buf(void *val, bool)  {
+    unsigned int val2buf(void *val, bool) override {
     	set_value(*reinterpret_cast<dods_int64*>(val));
     	return sizeof(dods_int64);
     }
     //virtual unsigned int buf2val(void **) { throw InternalErr(__FILE__, __LINE__, "Not implemented for Int64"); }
-    virtual unsigned int buf2val(void **); 
-    virtual void print_val(FILE *, string, bool) { throw InternalErr(__FILE__, __LINE__, "Not implemented for Int64"); }
+    unsigned int buf2val(void **) override; 
+    void print_val(FILE *, string, bool) override { throw InternalErr(__FILE__, __LINE__, "Not implemented for Int64"); }
 
 protected:
     dods_int64 d_buf;
@@ -69,25 +69,35 @@ public:
 
     virtual ~Int64();
 
-    virtual BaseType *ptr_duplicate();
+    BaseType *ptr_duplicate() override;
 
-    virtual unsigned int width(bool constrained = false) const;
+    unsigned int width(bool = false) const override
+    {
+        return sizeof(dods_int64);
+    }
+
+    int64_t width_ll(bool = false) const override
+    {
+        return sizeof(dods_int64);
+    }
 
     // DAP4
-    virtual void compute_checksum(Crc32 &checksum);
-    virtual void serialize(D4StreamMarshaller &m, DMR &dmr, /*ConstraintEvaluator &eval,*/ bool filter = false);
-    virtual void deserialize(D4StreamUnMarshaller &um, DMR &dmr);
+    void compute_checksum(Crc32 &checksum) override;
+    void serialize(D4StreamMarshaller &m, DMR &dmr, /*ConstraintEvaluator &eval,*/ bool filter = false) override;
+    void deserialize(D4StreamUnMarshaller &um, DMR &dmr) override;
 
     virtual bool set_value(dods_int64 i);
     virtual dods_int64 value() const;
 
-    virtual void print_val(ostream &out, string space = "", bool print_decl_p = true);
+    void print_val(ostream &out, string space = "", bool print_decl_p = true) override;
 
-    virtual bool ops(BaseType *b, int op);
-    virtual bool d4_ops(BaseType *b, int op);
-    virtual std::vector<BaseType *> *transform_to_dap2(AttrTable *parent_attr_table);
+    bool ops(BaseType *b, int op) override;
+    bool d4_ops(BaseType *b, int op) override;
+    std::vector<BaseType *> *transform_to_dap2(AttrTable *parent_attr_table) override;
 
-    virtual void dump(ostream &strm) const ;
+    bool is_dap4_projected(std::vector<string> &inventory) override;
+
+    void dump(ostream &strm) const override;
 };
 
 } // namespace libdap
