@@ -104,12 +104,6 @@ Int8::operator=(const Int8 &rhs)
     return *this;
 }
 
-unsigned int
-Int8::width(bool) const
-{
-    return sizeof(dods_int8);
-}
-
 void
 Int8::compute_checksum(Crc32 &checksum)
 {
@@ -238,6 +232,23 @@ Int8::transform_to_dap2(AttrTable *parent_attr_table)
     (*vec)[0]->set_type(dods_byte_c);
     return vec;
 }
+
+
+/**
+ * When send_p() is true a description of the instance is added to the inventory and true is returned.
+ * @param inventory is a value-result parameter
+ * @return True when send_p() is true, false otherwise
+ */
+bool Int8::is_dap4_projected(std::vector<std::string> &inventory)
+{
+    if(send_p()) {
+        attributes()->has_dap4_types(FQN(), inventory);
+        inventory.emplace_back(type_name() + " " + FQN());
+        return true;
+    }
+    return false;
+}
+
 /**
  * @brief dumps information about this object
  *
