@@ -241,7 +241,12 @@ static inline void delete_rows(BaseTypeRow *bt_row_ptr)
 
 Sequence::~Sequence()
 {
-    clear_local_data();
+    try {
+        Sequence::clear_local_data();   // make the call explicit in a destructor
+    }
+    catch (const std::exception &) {
+        // It's hard to know what to do - Log it when we can, but that can fail, too.
+    }
 }
 
 void Sequence::clear_local_data()
@@ -794,9 +799,11 @@ bool Sequence::serialize_leaf(DDS &dds, ConstraintEvaluator &eval, Marshaller &m
 void Sequence::intern_data(ConstraintEvaluator &eval, DDS &dds)
 {
     DBG(cerr << "Sequence::intern_data - for " << name() << endl); DBG2(cerr << "    intern_data, values: " << &d_values << endl);
+    if (is_dap4())
+        throw Error(string("A method usable only with DAP2 variables was called on a DAP4 variable (").append(name()).append(")."), __FILE__, __LINE__);
 
     // Why use a stack instead of return values? We need the stack because
-    // Sequences nested three of more levels deep will loose the middle
+    // Sequences nested three of more levels deep will lose the middle
     // instances when the intern_data_parent_part_two() code is run.
     sequence_values_stack_t sequence_values_stack;
 
