@@ -134,8 +134,8 @@ bool ServerFunctionsList::find_function(const std::string &name, bool_func *f) c
     std::pair <SFLCIter, SFLCIter> ret;
     ret = d_func_list.equal_range(name);
     for (SFLCIter it = ret.first; it != ret.second; ++it) {
-        if (name == it->first && (*f = it->second->get_bool_func())){
-            DBG(cerr << "ServerFunctionsList::find_function() - Found boolean function " << it->second->getName() << endl);
+        if (name == it->first && it->second->get_bool_func()) {
+            *f = it->second->get_bool_func();
             return true;
         }
     }
@@ -172,8 +172,8 @@ bool ServerFunctionsList::find_function(const string &name, btp_func *f) const
     std::pair <SFLCIter, SFLCIter> ret;
     ret = d_func_list.equal_range(name);
     for (SFLCIter it = ret.first; it != ret.second; ++it) {
-        if (name == it->first && (*f = it->second->get_btp_func())){
-            DBG(cerr << "ServerFunctionsList::find_function() - Found basetype function " << it->second->getName() << endl);
+        if (name == it->first && it->second->get_btp_func()) {
+            *f = it->second->get_btp_func();
             return true;
         }
     }
@@ -209,9 +209,9 @@ bool ServerFunctionsList::find_function(const string &name, proj_func *f) const
     std::pair <SFLCIter, SFLCIter> ret;
     ret = d_func_list.equal_range(name);
     for (SFLCIter it = ret.first; it != ret.second; ++it) {
-        if (name == it->first && (*f = it->second->get_proj_func())){
-            DBG(cerr << "ServerFunctionsList::find_function() - Found projection function " << it->second->getName() << endl);
-           return true;
+        if (name == it->first && it->second->get_proj_func()) {
+            *f = it->second->get_proj_func();
+            return true;
         }
     }
 
@@ -233,7 +233,8 @@ bool ServerFunctionsList::find_function(const string &name, D4Function *f) const
     std::pair <SFLCIter, SFLCIter> ret;
     ret = d_func_list.equal_range(name);
     for (SFLCIter it = ret.first; it != ret.second; ++it) {
-        if (name == it->first && (*f = it->second->get_d4_function())) {
+        if (name == it->first && it->second->get_d4_function()) {
+            *f = it->second->get_d4_function();
             return true;
         }
     }
