@@ -35,6 +35,8 @@
 #ifndef _vector_h
 #define _vector_h 1
 
+#include <cassert>
+
 #ifndef _basetype_h
 #include "BaseType.h"
 #endif
@@ -80,42 +82,48 @@ namespace libdap
 class Vector: public BaseType
 {
 private:
-    int d_length = -1;  		// number of elements in the vector
-    BaseType *d_proto = nullptr;  // element prototype for the Vector
+    // Add d_length_ll. This uses -1 as a sentinel value. jhrg 7/25/22
+    // If we decide to add a bool for 'no values yet' do that as a
+    // separate refactor. jhrg 7/25/22
+    int64_t d_length_ll = -1;  	// number of elements in the vector
+
+    int d_length = -1;  		    // number of elements in the vector
+    BaseType *d_proto = nullptr;    // element prototype for the Vector
 
     // _buf was a pointer to void; delete[] complained. 6/4/2001 jhrg
     char *d_buf = nullptr;   		// storage for cardinal data
-    vector<string> d_str;		// special storage for strings. jhrg 2/11/05
+    vector<string> d_str;		    // special storage for strings. jhrg 2/11/05
     vector<BaseType *> d_compound_buf; 	// storage for data in compound types (e.g., Structure)
 
     // the number of elements we have allocated memory to store.
     // This should be either the sizeof(buf)/width(bool constrained = false) for cardinal data
     // or the capacity of d_str for strings or capacity of _vec.
     unsigned int d_capacity = 0;
+    uint64_t d_capacity_ll = 0;
+
+    bool d_too_big_for_dap2 = false;    /// Conditionally set to true in set_length_ll()
 
     friend class MarshallerTest;
 
-    /*
-     * Made these template methods private because they can't be
-     * overridden anyways (because c++...) - ndp 08/14/2015
-     *
-     */
-
+    // Made these template methods private because they can't be
+    // overridden anyways (because c++...) - ndp 08/14/2015
     template <typename T> void value_worker(T *v) const;
+    template <typename T> void value_ll_worker(T *v) const;
     template <typename T> void value_worker(vector<unsigned int> *indices, T *b) const;
+    template <typename T> void value_ll_worker(vector<uint64_t> *indices, T *b) const;
 
     template <typename T> bool set_value_worker(T *v, int sz);
+    template <typename T> bool set_value_ll_worker(T *v, int64_t sz);
     template <typename T> bool set_value_worker(vector<T> &v, int sz);
-
-protected:
-    // This function copies the private members of Vector.
-    void m_duplicate(const Vector &v);
+    template <typename T> bool set_value_ll_worker(vector<T> &v, int64_t sz);
 
     bool m_is_cardinal_type() const;
-    unsigned int m_create_cardinal_data_buffer_for_type(unsigned int numEltsOfType);
+    int64_t m_create_cardinal_data_buffer_for_type(int64_t num_elements);
     void m_delete_cardinal_data_buffer();
+    template <class CardType> void m_set_cardinal_values_internal(const CardType* fromArray, int64_t num_elements);
 
-    template <class CardType> void m_set_cardinal_values_internal(const CardType* fromArray, int numElts);
+    // This function copies the private members of Vector.
+    void m_duplicate(const Vector &v);
 
 public:
     Vector(const string &n, BaseType *v, const Type &t, bool is_dap4 = false);
@@ -125,7 +133,7 @@ public:
     virtual ~Vector();
 
     Vector &operator=(const Vector &rhs);
-    virtual BaseType *ptr_duplicate() = 0;
+    // FIXME BaseType *ptr_duplicate() = 0 override;
 
     /**
      * Provide access to internal data. Callers cannot delete this
@@ -160,59 +168,110 @@ public:
         return d_compound_buf;
     }
 
-#if 0
-    virtual bool is_dap2_only_type();
-#endif
-
     virtual BaseType *prototype() const { return d_proto; }
 
-    virtual void set_name(const std::string& name);
+    /**
+     * @brief Change the Vector/Array element type
+     * @param btp
+     * @return The previous template, calling code is responsible for the returned BaseType lifecycle.
+     */
+    virtual BaseType *set_prototype(BaseType *btp) {  BaseType *orig = d_proto; d_proto = btp; return orig; }
 
-    virtual int element_count(bool leaves);
+    void set_name(const std::string& name) override;
 
-    virtual void set_send_p(bool state);
+    int element_count(bool leaves) override;
 
-    virtual void set_read_p(bool state);
+    void set_send_p(bool state) override;
 
-    virtual unsigned int width(bool constrained = false) const;
+    void set_read_p(bool state) override;
 
-    virtual int length() const;
+    /** Returns the number of bytes needed to hold the entire
+        array.  This is equal to \c length() (the number of elements in
+        in the array) times the width of each
+        element.
+
+        @brief Returns the width of the data, in bytes.
+        @deprecated Use width_ll() instead */
+    unsigned int width(bool constrained = false) const override
+    {
+        // Jose Garcia
+        assert(d_proto);
+
+        return length() * d_proto->width(constrained);
+    }
+
+    /**
+     * @brief Return the number of bytes needed to hold the array data
+     * @param constrained If true, return the number of bytes given the current constraint
+     * @return The number of bytes needed to hold the array data, as a 64-bit integer
+     */
+    int64_t width_ll(bool constrained = false) const override
+    {
+        return length_ll() * d_proto->width_ll(constrained);
+    }
+
+    /** @brief Returns the number of elements in the vector.
+     * Note that some child classes of Vector use the length of -1 as a flag value.
+     * @return The number of elements in the vector
+     * @deprecated Use length_ll() instead
+     */
+    int length() const override { return d_length; }
+
+    /** @brief Get the number of elements in this Vector/Array
+     * This version of the function deprecates length() which is limited to
+     * 32-bit sizes. The field uses -1 as a sentinel value indicating that
+     * the Vector/Array holds no values yet (as opposed to zero values).
+     * @return The number of elements in this Vector/Array
+     */
+    int64_t length_ll() const override { return d_length_ll; }
+
+    void set_length(int64_t l) override;
+
+    void set_length_ll(int64_t l) override;
 
-    virtual void set_length(int l);
 
     // DAP2
-    virtual void intern_data(ConstraintEvaluator &eval, DDS &dds);
-    virtual bool serialize(ConstraintEvaluator &eval, DDS &dds, Marshaller &m, bool ce_eval = true);
-#if 0
-    virtual bool serialize_no_release(ConstraintEvaluator &eval, DDS &dds, Marshaller &m, bool ce_eval = true);
-#endif
-    virtual bool deserialize(UnMarshaller &um, DDS *dds, bool reuse = false);
+    void intern_data(ConstraintEvaluator &eval, DDS &dds) override;
+    bool serialize(ConstraintEvaluator &eval, DDS &dds, Marshaller &m, bool ce_eval = true) override;
+    bool deserialize(UnMarshaller &um, DDS *dds, bool reuse = false) override;
 
     // DAP4
-    virtual void compute_checksum(Crc32 &checksum);
-    virtual void intern_data(/*Crc32 &checksum*/);
-    virtual void serialize(D4StreamMarshaller &m, DMR &dmr, bool filter = false);
-#if 0
-    virtual void serialize_no_release(D4StreamMarshaller &m, DMR &dmr, bool filter = false);
-#endif
-    virtual void deserialize(D4StreamUnMarshaller &um, DMR &dmr);
+    void compute_checksum(Crc32 &checksum) override;
+    void intern_data(/*Crc32 &checksum*/) override;
+    void serialize(D4StreamMarshaller &m, DMR &dmr, bool filter = false) override;
+    void deserialize(D4StreamUnMarshaller &um, DMR &dmr) override;
+
+    unsigned int val2buf(void *val, bool reuse = false) override;
+    unsigned int buf2val(void **val) override;
+
+    uint64_t val2buf_ll(void *val, bool reuse = false);
+    uint64_t buf2val_ll(void **val);
 
-    virtual unsigned int val2buf(void *val, bool reuse = false);
-    virtual unsigned int buf2val(void **val);
 
     void set_vec(unsigned int i, BaseType *val);
     void set_vec_nocopy(unsigned int i, BaseType * val);
 
+    void set_vec_ll(uint64_t i, BaseType *val);
+    void set_vec_nocopy_ll(uint64_t i, BaseType * val);
+
     void vec_resize(int l);
+    void vec_resize_ll(int64_t l);
+
+    void clear_local_data() override;
 
-    virtual void clear_local_data();
 
     virtual unsigned int get_value_capacity() const;
+    virtual uint64_t get_value_capacity_ll() const;
+
+    void set_value_capacity(uint64_t l);
     virtual void reserve_value_capacity(unsigned int numElements);
     virtual void reserve_value_capacity();
+    virtual void reserve_value_capacity_ll(uint64_t numElements);
+    virtual void reserve_value_capacity_ll();
 
-    virtual unsigned int set_value_slice_from_row_major_vector(const Vector& rowMajorData, unsigned int startElement);
+    virtual void reserve_value_capacity_ll_byte(uint64_t numBytes);
 
+    virtual uint64_t set_value_slice_from_row_major_vector(const Vector& rowMajorData, uint64_t startElement);
 
     virtual bool set_value(dods_byte *val, int sz);
     virtual bool set_value(dods_int8 *val, int sz);
@@ -227,6 +286,18 @@ public:
     virtual bool set_value(string *val, int sz);
 
 
+    virtual bool set_value_ll(dods_byte *val, int64_t sz);
+    virtual bool set_value_ll(dods_int8 *val, int64_t sz);
+    virtual bool set_value_ll(dods_int16 *val, int64_t sz);
+    virtual bool set_value_ll(dods_uint16 *val, int64_t sz);
+    virtual bool set_value_ll(dods_int32 *val, int64_t sz);
+    virtual bool set_value_ll(dods_uint32 *val, int64_t sz);
+    virtual bool set_value_ll(dods_int64 *val, int64_t sz);
+    virtual bool set_value_ll(dods_uint64 *val, int64_t sz);
+    virtual bool set_value_ll(dods_float32 *val, int64_t sz);
+    virtual bool set_value_ll(dods_float64 *val, int64_t sz);
+    virtual bool set_value_ll(string *val, int64_t sz);
+
     virtual bool set_value(vector<dods_byte> &val, int sz);
     virtual bool set_value(vector<dods_int8> &val, int sz);
     virtual bool set_value(vector<dods_int16> &val, int sz);
@@ -239,6 +310,20 @@ public:
     virtual bool set_value(vector<dods_float64> &val, int sz);
     virtual bool set_value(vector<string> &val, int sz);
 
+    virtual bool set_value_ll(vector<dods_byte> &val, int64_t sz);
+    virtual bool set_value_ll(vector<dods_int8> &val, int64_t sz);
+    virtual bool set_value_ll(vector<dods_int16> &val, int64_t sz);
+    virtual bool set_value_ll(vector<dods_uint16> &val, int64_t sz);
+    virtual bool set_value_ll(vector<dods_int32> &val, int64_t sz);
+    virtual bool set_value_ll(vector<dods_uint32> &val, int64_t sz);
+    virtual bool set_value_ll(vector<dods_int64> &val, int64_t sz);
+    virtual bool set_value_ll(vector<dods_uint64> &val, int64_t sz);
+    virtual bool set_value_ll(vector<dods_float32> &val, int64_t sz);
+    virtual bool set_value_ll(vector<dods_float64> &val, int64_t sz);
+    virtual bool set_value_ll(vector<string> &val, int64_t sz);
+
+
+
     virtual void value(dods_byte *b) const;
     virtual void value(dods_int8 *b) const;
     virtual void value(dods_int16 *b) const;
@@ -263,18 +348,35 @@ public:
     virtual void value(vector<unsigned int> *indices, dods_float64 *b) const;
     virtual void value(vector<unsigned int> *index, vector<string> &b) const;
 
+    virtual void value_ll(vector<uint64_t> *indices, dods_byte *b) const;
+    virtual void value_ll(vector<uint64_t> *indices, dods_int8 *b) const;
+    virtual void value_ll(vector<uint64_t> *indices, dods_int16 *b) const;
+    virtual void value_ll(vector<uint64_t> *indices, dods_uint16 *b) const;
+    virtual void value_ll(vector<uint64_t> *indices, dods_int32 *b) const;
+    virtual void value_ll(vector<uint64_t> *indices, dods_uint32 *b) const;
+    virtual void value_ll(vector<uint64_t> *indices, dods_int64 *b) const;
+    virtual void value_ll(vector<uint64_t> *indices, dods_uint64 *b) const;
+    virtual void value_ll(vector<uint64_t> *indices, dods_float32 *b) const;
+    virtual void value_ll(vector<uint64_t> *indices, dods_float64 *b) const;
+    virtual void value_ll(vector<uint64_t> *index, vector<string> &b) const;
+
+
     virtual void *value();
 
-    virtual BaseType *var(const string &name = "", bool exact_match = true, btp_stack *s = 0);
-    virtual BaseType *var(const string &name, btp_stack &s);
+    BaseType *var(const string &name = "", bool exact_match = true, btp_stack *s = nullptr) override;
+    BaseType *var(const string &name, btp_stack &s) override;
+
     virtual BaseType *var(unsigned int i);
+    virtual BaseType *var_ll(uint64_t i);
 
-    virtual void add_var(BaseType *v, Part p = nil);
-    virtual void add_var_nocopy(BaseType *v, Part p = nil);
+    void add_var(BaseType *v, Part p = nil) override;
+    void add_var_nocopy(BaseType *v, Part p = nil) override;
 
-    virtual bool check_semantics(string &msg, bool all = false);
+    bool check_semantics(string &msg, bool all = false) override;
 
-    virtual void dump(ostream &strm) const ;
+    bool is_dap4_projected(std::vector<std::string> &projected_dap4_inventory) override;
+
+    void dump(ostream &strm) const override;
 };
 
 } // namespace libdap
