@@ -155,18 +155,19 @@ static const char *months[] =
 string
 rfc822_date(const time_t t)
 {
-    struct tm *stm = gmtime(&t);
-    if (!stm)
+    struct tm stm;
+    const struct tm *ret = gmtime_r(&t, &stm);
+    if (!ret)
     	return "";
 
     char d[256];
 
-    snprintf(d, 255, "%s, %02d %s %4d %02d:%02d:%02d GMT", days[stm->tm_wday],
-            stm->tm_mday, months[stm->tm_mon],
-            1900 + stm->tm_year,
-            stm->tm_hour, stm->tm_min, stm->tm_sec);
+    snprintf(d, 255, "%s, %02d %s %4d %02d:%02d:%02d GMT", days[stm.tm_wday],
+            stm.tm_mday, months[stm.tm_mon],
+            1900 + stm.tm_year,
+            stm.tm_hour, stm.tm_min, stm.tm_sec);
     d[255] = '\0';
-    return string(d);
+    return {d};
 }
 
 static const int TimLen = 26; // length of string from asctime()
@@ -227,17 +228,14 @@ ErrMsgT(const string &Msgt)
     if (time(&TimBin) == (time_t) - 1)
         strncpy(TimStr, "time() error           ", TimLen-1);
     else {
-    	char *ctime_value = ctime(&TimBin);
-    	if (!ctime_value)
+        char ctime_value[TimLen];
+    	const char *ret = ctime_r(&TimBin, ctime_value);
+    	if (!ret)
     		strncpy(TimStr, "Unknown", TimLen-1);
     	else {
     		strncpy(TimStr, ctime_value, TimLen-1);
     		TimStr[TimLen - 2] = '\0'; // overwrite the \n
     	}
-#if 0
-    	strncpy(TimStr, ctime(&TimBin), TimLen-1);
-    	TimStr[TimLen - 2] = '\0'; // overwrite the \n
-#endif
     }
 
     cerr << "[" << TimStr << "] DAP server error: " << Msgt << endl;
@@ -916,12 +914,12 @@ void parse_mime_header(const string &header, string &name, string &value)
     size_t length = header.length() + 1;
     vector<char> s(length);
     //char s[line_length];
-    iss.getline(&s[0], length, ':');
-    name = &s[0];
+    iss.getline(s.data(), length, ':');
+    name = s.data();
 
     iss.ignore(length, ' ');
-    iss.getline(&s[0], length);
-    value = &s[0];
+    iss.getline(s.data(), length);
+    value = s.data();
 
     downcase(name);
     downcase(value);
