@@ -52,17 +52,13 @@
 #include "crc.h"
 #include "D4Attributes.h"
 
-#include "GetOpt.h" // Added jhrg
+#include "run_tests_cppunit.h"
+#include "run_tests_cppunit.h"
+#include "test_config.h"
+
 
 #include "testFile.h"
 
-/// Added jhrg
-static bool debug = false;
-
-#undef DBG
-#define DBG(x) do { if (debug) (x); } while(false);
-/// jhrg
-
 using namespace CppUnit;
 using namespace std;
 using namespace libdap;
@@ -389,49 +385,5 @@ CPPUNIT_TEST_SUITE_REGISTRATION (ByteTest);
 
 int main(int argc, char *argv[])
 {
-    GetOpt getopt(argc, argv, "dh");
-    int option_char;
-
-    while ((option_char = getopt()) != -1)
-        switch (option_char) {
-        case 'd':
-            debug = 1;  // debug is a static global
-            break;
-
-        case 'h': {     // help - show test names
-            cerr << "Usage: ByteTest has the following tests:" << endl;
-            // Since the ByteTest class is not in the namespace 'libdap' using the ns
-            // prefix is a compiler error. Somce of the tests do put the code in a ns
-            // and then you will need to use the match prefix. jhrg
-            const std::vector<Test*> &tests = /*libdap:: jhrg*/ByteTest::suite()->getTests();
-            unsigned int prefix_len = /*libdap:: jhrg*/ByteTest::suite()->getName().append("::").length();
-            for (std::vector<Test*>::const_iterator i = tests.begin(), e = tests.end(); i != e; ++i) {
-                cerr << (*i)->getName().replace(0, prefix_len, "") << endl;
-            }
-            break;
-        }
-
-        default:
-            break;
-        }
-
-    CppUnit::TextTestRunner runner;
-    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
-
-    bool wasSuccessful = true;
-    string test = "";
-    int i = getopt.optind;
-    if (i == argc) {
-        // run them all
-        wasSuccessful = runner.run("");
-    }
-    else {
-        for (; i < argc; ++i) {
-            if (debug) cerr << "Running " << argv[i] << endl;
-            test = /*libdap:: jhrg*/ByteTest::suite()->getName().append("::").append(argv[i]);
-            wasSuccessful = wasSuccessful && runner.run(test);
-        }
-    }
-
-    return wasSuccessful ? 0 : 1;
+    return run_tests<ByteTest>(argc, argv) ? 0: 1;
 }
