@@ -49,17 +49,12 @@
 #include "D4FilterClause.h"
 #include "DMR.h"    // We need this because D4FilterClause::value needs it (sort of).
 
-#include "GetOpt.h"
+
 #include "util.h"
 #include "debug.h"
 
-//#include "testFile.h"
-//#include "test_config.h"
-
-static bool debug = false;
-
-#undef DBG
-#define DBG(x) do { if (debug) {x;} } while(false)
+#include "run_tests_cppunit.h"
+#include "test_config.h"
 
 using namespace CppUnit;
 using namespace std;
@@ -117,25 +112,25 @@ public:
         D4RValue *arg1 = new D4RValue(byte);    // holds 17
         D4RValue *arg2 = new D4RValue((long long) 21);
 
-        auto_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
+        unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
         CPPUNIT_ASSERT(less->value(dmr));
 
         D4RValue *arg2_1 = new D4RValue(byte);    // holds 17
         D4RValue *arg2_2 = new D4RValue((long long) 21);
 
-        auto_ptr<D4FilterClause> greater(new D4FilterClause(D4FilterClause::greater, arg2_1, arg2_2));
+        unique_ptr<D4FilterClause> greater(new D4FilterClause(D4FilterClause::greater, arg2_1, arg2_2));
         CPPUNIT_ASSERT(!greater->value(dmr));
 
         D4RValue *arg3_1 = new D4RValue(byte);    // holds 17
         D4RValue *arg3_2 = new D4RValue((long long) 21);
 
-        auto_ptr<D4FilterClause> equal(new D4FilterClause(D4FilterClause::equal, arg3_1, arg3_2));
+        unique_ptr<D4FilterClause> equal(new D4FilterClause(D4FilterClause::equal, arg3_1, arg3_2));
         CPPUNIT_ASSERT(!equal->value(dmr));
 
         D4RValue *arg4_1 = new D4RValue(byte);    // holds 17
         D4RValue *arg4_2 = new D4RValue((long long) 21);
 
-        auto_ptr<D4FilterClause> not_equal(new D4FilterClause(D4FilterClause::not_equal, arg4_1, arg4_2));
+        unique_ptr<D4FilterClause> not_equal(new D4FilterClause(D4FilterClause::not_equal, arg4_1, arg4_2));
         CPPUNIT_ASSERT(not_equal->value(dmr));
     }
 
@@ -145,25 +140,25 @@ public:
         D4RValue *arg1 = new D4RValue(byte);    // holds 17
         D4RValue *arg2 = new D4RValue((long long) 21);
 
-        auto_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
+        unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
         CPPUNIT_ASSERT(less->value());
 
         D4RValue *arg2_1 = new D4RValue(byte);    // holds 17
         D4RValue *arg2_2 = new D4RValue((long long) 21);
 
-        auto_ptr<D4FilterClause> greater(new D4FilterClause(D4FilterClause::greater, arg2_1, arg2_2));
+        unique_ptr<D4FilterClause> greater(new D4FilterClause(D4FilterClause::greater, arg2_1, arg2_2));
         CPPUNIT_ASSERT(!greater->value());
 
         D4RValue *arg3_1 = new D4RValue(byte);    // holds 17
         D4RValue *arg3_2 = new D4RValue((long long) 21);
 
-        auto_ptr<D4FilterClause> equal(new D4FilterClause(D4FilterClause::equal, arg3_1, arg3_2));
+        unique_ptr<D4FilterClause> equal(new D4FilterClause(D4FilterClause::equal, arg3_1, arg3_2));
         CPPUNIT_ASSERT(!equal->value());
 
         D4RValue *arg4_1 = new D4RValue(byte);    // holds 17
         D4RValue *arg4_2 = new D4RValue((long long) 21);
 
-        auto_ptr<D4FilterClause> not_equal(new D4FilterClause(D4FilterClause::not_equal, arg4_1, arg4_2));
+        unique_ptr<D4FilterClause> not_equal(new D4FilterClause(D4FilterClause::not_equal, arg4_1, arg4_2));
         CPPUNIT_ASSERT(not_equal->value());
     }
 
@@ -172,25 +167,25 @@ public:
         D4RValue *arg1 = new D4RValue(byte);    // holds 17
         D4RValue *arg2 = new D4RValue((double) 21.0);
 
-        auto_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
+        unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
         CPPUNIT_ASSERT(less->value(dmr));
 
         D4RValue *arg2_1 = new D4RValue(byte);    // holds 17
         D4RValue *arg2_2 = new D4RValue((double) 21);
 
-        auto_ptr<D4FilterClause> greater(new D4FilterClause(D4FilterClause::greater, arg2_1, arg2_2));
+        unique_ptr<D4FilterClause> greater(new D4FilterClause(D4FilterClause::greater, arg2_1, arg2_2));
         CPPUNIT_ASSERT(!greater->value(dmr));
 
         D4RValue *arg3_1 = new D4RValue(byte);    // holds 17
         D4RValue *arg3_2 = new D4RValue((double) 21);
 
-        auto_ptr<D4FilterClause> equal(new D4FilterClause(D4FilterClause::equal, arg3_1, arg3_2));
+        unique_ptr<D4FilterClause> equal(new D4FilterClause(D4FilterClause::equal, arg3_1, arg3_2));
         CPPUNIT_ASSERT(!equal->value(dmr));
 
         D4RValue *arg4_1 = new D4RValue(byte);    // holds 17
         D4RValue *arg4_2 = new D4RValue((double) 21);
 
-        auto_ptr<D4FilterClause> not_equal(new D4FilterClause(D4FilterClause::not_equal, arg4_1, arg4_2));
+        unique_ptr<D4FilterClause> not_equal(new D4FilterClause(D4FilterClause::not_equal, arg4_1, arg4_2));
         CPPUNIT_ASSERT(not_equal->value(dmr));
     }
 
@@ -202,7 +197,7 @@ public:
         D4RValue *arg1 = new D4RValue(byte);    // holds 17
         D4RValue *arg2 = new D4RValue((unsigned long long) (21));
 
-        auto_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
+        unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
         CPPUNIT_ASSERT(less->value());
 
     }
@@ -212,7 +207,7 @@ public:
         D4RValue *arg1 = new D4RValue(byte);    // holds 17
         D4RValue *arg2 = new D4RValue((float) 21.0);
 
-        auto_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
+        unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
         CPPUNIT_ASSERT(less->value());
 
     }
@@ -224,25 +219,25 @@ public:
         D4RValue *arg1 = new D4RValue(str);
         D4RValue *arg2 = new D4RValue(string("Tesla"));
 
-        auto_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
+        unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
         CPPUNIT_ASSERT(less->value());
 
         D4RValue *arg2_1 = new D4RValue(str);
         D4RValue *arg2_2 = new D4RValue("Tesla");
 
-        auto_ptr<D4FilterClause> greater(new D4FilterClause(D4FilterClause::greater, arg2_1, arg2_2));
+        unique_ptr<D4FilterClause> greater(new D4FilterClause(D4FilterClause::greater, arg2_1, arg2_2));
         CPPUNIT_ASSERT(!greater->value());
 
         D4RValue *arg3_1 = new D4RValue(str);
         D4RValue *arg3_2 = new D4RValue("Tesla");
 
-        auto_ptr<D4FilterClause> equal(new D4FilterClause(D4FilterClause::equal, arg3_1, arg3_2));
+        unique_ptr<D4FilterClause> equal(new D4FilterClause(D4FilterClause::equal, arg3_1, arg3_2));
         CPPUNIT_ASSERT(!equal->value(dmr));
 
         D4RValue *arg4_1 = new D4RValue(str);
         D4RValue *arg4_2 = new D4RValue("Tesla");
 
-        auto_ptr<D4FilterClause> not_equal(new D4FilterClause(D4FilterClause::not_equal, arg4_1, arg4_2));
+        unique_ptr<D4FilterClause> not_equal(new D4FilterClause(D4FilterClause::not_equal, arg4_1, arg4_2));
         CPPUNIT_ASSERT(not_equal->value(dmr));
     }
 
@@ -251,7 +246,7 @@ public:
         D4RValue *arg1 = new D4RValue(str);
         D4RValue *arg2 = new D4RValue(string("E.*n"));
 
-        auto_ptr<D4FilterClause> match(new D4FilterClause(D4FilterClause::match, arg1, arg2));
+        unique_ptr<D4FilterClause> match(new D4FilterClause(D4FilterClause::match, arg1, arg2));
         CPPUNIT_ASSERT(match->value());
     }
 
@@ -261,7 +256,7 @@ public:
         D4RValue *arg2 = new D4RValue((long long) 21);
 
         try {
-            auto_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
+            unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
             // The Filter Clause instance is built OK, but the value() method
             // will balk at this comparison. jhrg 4/21/16
             DBG(cerr << "built filter clause instance" << endl);
@@ -281,7 +276,7 @@ public:
         D4RValue *arg2 = new D4RValue("Tesla");
 
         try {
-            auto_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
+            unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
 
             CPPUNIT_ASSERT(less->value());
             CPPUNIT_FAIL("Expected error");
@@ -294,13 +289,13 @@ public:
 
     void Structure_and_string_error_test()
     {
-        auto_ptr<Structure> s(new Structure("s"));
+        unique_ptr<Structure> s(new Structure("s"));
         s->add_var(byte); // copy the object
         D4RValue *arg1 = new D4RValue(s.get()); // BaseType*s are not free'd by D4RValue
         D4RValue *arg2 = new D4RValue("Tesla");
 
         try {
-            auto_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
+            unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
 
             CPPUNIT_ASSERT(less->value());
             CPPUNIT_FAIL("Expected error");
@@ -314,13 +309,13 @@ public:
     // There's no way this will get past the parser, but ...
     void Byte_and_Structure_error_test()
     {
-        auto_ptr<Structure> s(new Structure("s"));
+        unique_ptr<Structure> s(new Structure("s"));
         s->add_var(str); // copy the object
         D4RValue *arg1 = new D4RValue(byte);
         D4RValue *arg2 = new D4RValue(s.get());
 
         try {
-            auto_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
+            unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
 
             CPPUNIT_ASSERT(less->value());
             CPPUNIT_FAIL("Expected error");
@@ -334,13 +329,13 @@ public:
     // There's no way this will get past the parser, but ...
     void Str_and_Structure_error_test()
     {
-        auto_ptr<Structure> s(new Structure("s"));
+        unique_ptr<Structure> s(new Structure("s"));
         s->add_var(str); // copy the object
         D4RValue *arg1 = new D4RValue(str);
         D4RValue *arg2 = new D4RValue(s.get());
 
         try {
-            auto_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
+            unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
 
             CPPUNIT_ASSERT(less->value());
             CPPUNIT_FAIL("Expected error");
@@ -357,25 +352,25 @@ public:
         D4RValue *arg2_1 = new D4RValue(f32);
         D4RValue *arg2_2 = new D4RValue(17.0);
 
-        auto_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg2_1, arg2_2));
+        unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg2_1, arg2_2));
         CPPUNIT_ASSERT(less->value());
 
         D4RValue *arg3_1 = new D4RValue(url);
         D4RValue *arg3_2 = new D4RValue("https://github.com/opendap");
 
-        auto_ptr<D4FilterClause> equal(new D4FilterClause(D4FilterClause::equal, arg3_1, arg3_2));
+        unique_ptr<D4FilterClause> equal(new D4FilterClause(D4FilterClause::equal, arg3_1, arg3_2));
         CPPUNIT_ASSERT(equal->value(dmr));
 
         D4RValue *arg4_1 = new D4RValue(url);
         D4RValue *arg4_2 = new D4RValue("https://.*dap$");
 
-        auto_ptr<D4FilterClause> not_equal(new D4FilterClause(D4FilterClause::not_equal, arg4_1, arg4_2));
+        unique_ptr<D4FilterClause> not_equal(new D4FilterClause(D4FilterClause::not_equal, arg4_1, arg4_2));
         CPPUNIT_ASSERT(not_equal->value(dmr));
 
         D4RValue *arg5_1 = new D4RValue(url);
         D4RValue *arg5_2 = new D4RValue("https://.*dap$");
 
-        auto_ptr<D4FilterClause> match(new D4FilterClause(D4FilterClause::match, arg5_1, arg5_2));
+        unique_ptr<D4FilterClause> match(new D4FilterClause(D4FilterClause::match, arg5_1, arg5_2));
         CPPUNIT_ASSERT(match->value(dmr));
     }
 
@@ -384,7 +379,7 @@ public:
         D4RValue *arg2_1 = new D4RValue(f32);
         D4RValue *arg2_2 = new D4RValue(3.1415);
 
-        auto_ptr<D4FilterClause> clause(new D4FilterClause(D4FilterClause::equal, arg2_1, arg2_2));
+        unique_ptr<D4FilterClause> clause(new D4FilterClause(D4FilterClause::equal, arg2_1, arg2_2));
         CPPUNIT_ASSERT(clause->value());
     }
 
@@ -393,7 +388,7 @@ public:
         D4RValue *arg2_1 = new D4RValue(f32);
         D4RValue *arg2_2 = new D4RValue(3.1415);
 
-        auto_ptr<D4FilterClause> clause(new D4FilterClause(D4FilterClause::greater_equal, arg2_1, arg2_2));
+        unique_ptr<D4FilterClause> clause(new D4FilterClause(D4FilterClause::greater_equal, arg2_1, arg2_2));
         CPPUNIT_ASSERT(clause->value());
     }
 
@@ -402,25 +397,25 @@ public:
         D4RValue *arg2_1 = new D4RValue(f32);
         D4RValue *arg2_2 = new D4RValue(3.1415);
 
-        auto_ptr<D4FilterClause> clause(new D4FilterClause(D4FilterClause::less_equal, arg2_1, arg2_2));
+        unique_ptr<D4FilterClause> clause(new D4FilterClause(D4FilterClause::less_equal, arg2_1, arg2_2));
         CPPUNIT_ASSERT(clause->value());
     }
 
     void int_test()
     {
-        auto_ptr<Int8> i8(new Int8(""));
+        unique_ptr<Int8> i8(new Int8(""));
         i8->set_value(17);
         D4RValue *arg2_1 = new D4RValue(i8.get());
         D4RValue *arg2_2 = new D4RValue((long long) 17);
 
-        auto_ptr<D4FilterClause> clause(new D4FilterClause(D4FilterClause::equal, arg2_1, arg2_2));
+        unique_ptr<D4FilterClause> clause(new D4FilterClause(D4FilterClause::equal, arg2_1, arg2_2));
         CPPUNIT_ASSERT(clause->value());
     }
 
     void true_clauses_test()
     {
         // Testing this as a pointer since that's how it will be stored in D4Sequence
-        auto_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
+        unique_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
 
         D4RValue *arg1_1 = new D4RValue(byte);    // holds 17
         D4RValue *arg1_2 = new D4RValue((double) 21.0);
@@ -446,7 +441,7 @@ public:
     // This should return true
     void no_clauses_test()
     {
-        auto_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
+        unique_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
 
         CPPUNIT_ASSERT(clauses->size() == 0);
         CPPUNIT_ASSERT(clauses->value(dmr));
@@ -455,7 +450,7 @@ public:
 
     void false_clauses_test()
     {
-        auto_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
+        unique_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
 
         D4RValue *arg1_1 = new D4RValue(byte);    // holds 17
         D4RValue *arg1_2 = new D4RValue((double) 21.0);
@@ -481,7 +476,7 @@ public:
 
     void evaluation_order_test()
     {
-        auto_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
+        unique_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
 
         D4RValue *arg1_1 = new D4RValue(byte);    // holds 17
         D4RValue *arg1_2 = new D4RValue((double) 21.0);
@@ -515,7 +510,7 @@ public:
 
     void evaluation_order_test_2()
     {
-        auto_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
+        unique_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
 
         D4RValue *arg1_1 = new D4RValue(byte);    // holds 17
         D4RValue *arg1_2 = new D4RValue((double) 21.0);
@@ -586,45 +581,5 @@ CPPUNIT_TEST_SUITE_REGISTRATION (D4FilterClauseTest);
 
 int main(int argc, char*argv[])
 {
-    GetOpt getopt(argc, argv, "dh");
-    int option_char;
-
-    while ((option_char = getopt()) != EOF)
-        switch (option_char) {
-        case 'd':
-            debug = 1;  // debug is a static global
-            break;
-        case 'h': {     // help - show test names
-            cerr << "Usage: D4FilterClauseTest has the following tests:" << endl;
-            const std::vector<Test*> &tests = libdap::D4FilterClauseTest::suite()->getTests();
-            unsigned int prefix_len = libdap::D4FilterClauseTest::suite()->getName().append("::").length();
-            for (std::vector<Test*>::const_iterator i = tests.begin(), e = tests.end(); i != e; ++i) {
-                cerr << (*i)->getName().replace(0, prefix_len, "") << endl;
-            }
-            break;
-        }
-        default:
-            break;
-        }
-
-    CppUnit::TextTestRunner runner;
-    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
-
-    bool wasSuccessful = true;
-    string test = "";
-    int i = getopt.optind;
-    if (i == argc) {
-        // run them all
-        wasSuccessful = runner.run("");
-    }
-    else {
-        for (; i < argc; ++i) {
-            if (debug) cerr << "Running " << argv[i] << endl;
-            test = libdap::D4FilterClauseTest::suite()->getName().append("::").append(argv[i]);
-            wasSuccessful = wasSuccessful && runner.run(test);
-        }
-    }
-
-    return wasSuccessful ? 0 : 1;
+    return run_tests<libdap::D4FilterClauseTest>(argc, argv) ? 0: 1;
 }
-
