@@ -30,13 +30,15 @@
 
 #include "DAS.h"
 #include "debug.h"
-#include <test_config.h>
-#include "GetOpt.h"
+#include "run_tests_cppunit.h"
+#include "test_config.h"
+
+
 
 using namespace CppUnit;
 using namespace libdap;
 
-static bool debug = false;
+
 
 class DASTest: public TestFixture {
 private:
@@ -98,44 +100,5 @@ CPPUNIT_TEST_SUITE_REGISTRATION (DASTest);
 
 int main(int argc, char*argv[])
 {
-    GetOpt getopt(argc, argv, "dh");
-    int option_char;
-
-    while ((option_char = getopt()) != -1)
-        switch (option_char) {
-        case 'd':
-            debug = true;  // debug is a static global
-            break;
-        case 'h': {     // help - show test names
-            cerr << "Usage: DASTest has the following tests:" << endl;
-            const std::vector<Test*> &tests = DASTest::suite()->getTests();
-            unsigned int prefix_len = DASTest::suite()->getName().append("::").length();
-            for (std::vector<Test*>::const_iterator i = tests.begin(), e = tests.end(); i != e; ++i) {
-                cerr << (*i)->getName().replace(0, prefix_len, "") << endl;
-            }
-            break;
-        }
-        default:
-            break;
-        }
-
-    CppUnit::TextTestRunner runner;
-    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
-
-    bool wasSuccessful = true;
-    string test = "";
-    int i = getopt.optind;
-    if (i == argc) {
-        // run them all
-        wasSuccessful = runner.run("");
-    }
-    else {
-        for (; i < argc; ++i) {
-            if (debug) cerr << "Running " << argv[i] << endl;
-            test = DASTest::suite()->getName().append("::").append(argv[i]);
-            wasSuccessful = wasSuccessful && runner.run(test);
-        }
-    }
-
-    return wasSuccessful ? 0 : 1;
+    return run_tests<DASTest>(argc, argv) ? 0: 1;
 }
