@@ -105,17 +105,17 @@ public:
     CPPUNIT_TEST (top_level_simple_types_test_file_stream);
     CPPUNIT_TEST (structure_test_file_ptr);
 
-#if 0
     // All of these fail; maybe because on OSX 10.9 something about
     // libxml2 is odd. Investigate. jhrg 2/4/14
     // FIXME
+    // The following C++ Stream I/O tests work on MacOS 11, we will turn on
+    // and see if it can pass other MacOS. KY 11/10/22
 
     // C++ Stream I/O tests
     CPPUNIT_TEST(top_level_simple_types_test_cpp_stream);
     CPPUNIT_TEST(structure_test_cpp_stream);
     CPPUNIT_TEST(sequence_test_cpp_stream);
     CPPUNIT_TEST(grid_test_cpp_stream);
-#endif
     // Error tests
     CPPUNIT_TEST (unknown_tag_test);
     CPPUNIT_TEST (bad_nesting_test);
