@@ -50,7 +50,7 @@ namespace libdap {
 
 class HTTPConnectTest: public TestFixture {
 private:
-    HTTPConnect * http;
+    HTTPConnect * http{};
     string localhost_url, localhost_pw_url, localhost_digest_pw_url;
     string etag;
     string lm;
@@ -66,13 +66,12 @@ protected:
 
     struct REMatch: public unary_function<const string &, bool> {
         Regex &d_re;
-        REMatch(Regex &re) :
+        explicit REMatch(Regex &re) :
             d_re(re)
         {
         }
-        ~REMatch()
-        {
-        }
+        ~REMatch() = default;
+
         bool operator()(const string &str)
         {
             const char *s = str.c_str();
@@ -85,7 +84,7 @@ protected:
     class HeaderMatch: public unary_function<const string &, bool> {
         const string &d_header;
     public:
-        HeaderMatch(const string &header) :
+        explicit HeaderMatch(const string &header) :
             d_header(header)
         {
         }
@@ -96,20 +95,22 @@ protected:
     };
 
 public:
-    HTTPConnectTest()
+    HTTPConnectTest(): http(nullptr)
     {
     }
-    ~HTTPConnectTest()
+    ~HTTPConnectTest() override
     {
     }
 
-    void setUp()
+    void setUp() override
     {
+        DBG(cerr << endl);
         DBG(cerr << prolog << "Setting the DODS_CONF env var" << endl);
         setenv("DODS_CONF", "cache-testsuite/dodsrc", 1);
         http = new HTTPConnect(RCReader::instance());
 
         localhost_url = "http://test.opendap.org/test-304.html";
+        DBG(cerr << prolog << "localhost_url: " << localhost_url<< endl);
 
         // Two request header values that will generate a 304 response to the
         // above URL. The values below much match the etag and last-modified
@@ -119,12 +120,24 @@ public:
         // etag = "\"a10df-157-139c2680\"";
         // etag = "\"2a008e-157-3fbcd139c2680\"";
         // etag = "\"181893-157-3fbcd139c2680\""; // On 10/13/14 we moved to a new httpd and the etag value changed.
-        etag ="\"157-3df1e87884680\""; // New httpd service, new etag, ndp - 01/11/21
+        // etag ="\"157-3df1e87884680\""; // New httpd service, new etag, ndp - 01/11/21
+        etag = "\"157-3df0e26958000\"";// New httpd (dockerized), new etag. ndp - 12/06/22
+        DBG(cerr << prolog << "etag: " << etag<< endl);
         lm = "Wed, 13 Jul 2005 19:32:26 GMT";
+        DBG(cerr << prolog << "lm: " << lm<< endl);
+        string u("jimg");
+        string dt(":dods_test@");
+        string dd(":dods_digest@");
+        string page("test.opendap.org/basic/page.txt");
+
+        localhost_pw_url = "http://"+u+dt+page;
+        DBG(cerr << prolog << "localhost_pw_url: " << localhost_pw_url<< endl);
+
+        localhost_digest_pw_url = "http://"+u+dd+page;
+        DBG(cerr << prolog << "localhost_digest_pw_url: " << localhost_digest_pw_url<< endl);
 
-        localhost_pw_url = "http://jimg:dods_test@test.opendap.org/basic/page.txt";
-        localhost_digest_pw_url = "http://jimg:dods_digest@test.opendap.org/digest/page.txt";
         netcdf_das_url = "http://test.opendap.org/dap/data/nc/fnoc1.nc.das";
+        DBG(cerr << prolog << "netcdf_das_url: " << netcdf_das_url<< endl);
     }
 
     void tearDown()
@@ -133,7 +146,7 @@ public:
         // this here make valgrind think there are leaks.
         http->d_http_cache->delete_instance();
         delete http;
-        http = 0;
+        http = nullptr;
         unsetenv("DODS_CONF");
     }
 
@@ -182,22 +195,28 @@ public:
             vector<string> request_h;
 
             // First test using a time with if-modified-since
+            DBG(cerr << prolog << "If-Modified-Since test. BEGIN " << endl);
             request_h.push_back(string("If-Modified-Since: ") + lm);
             status = http->read_url(localhost_url, dump, resp_h, &request_h);
             DBG(cerr << prolog << "If modified since test. Returned http status: " << status << endl);
+            DBG(cerr << prolog << "Response Headers: " << endl);
             DBG(copy(resp_h->begin(), resp_h->end(), ostream_iterator<string>(cerr, "\n")));
             DBG(cerr << endl);
             CPPUNIT_ASSERT(status == 304);
+            DBG(cerr << prolog << "If-Modified-Since test. END " << endl);
 
             // Now test an etag
+            DBG(cerr << prolog << "ETag (If-None_Match) test. BEGIN (etag:" << etag << ")"<< endl);
             resp_h->clear();
             request_h.clear();
             request_h.push_back(string("If-None-Match: ") + etag);
             status = http->read_url(localhost_url, dump, resp_h, &request_h);
-            DBG(cerr << prolog << "If none match test. Returned http status: " << status << endl);
+            DBG(cerr << prolog << "ETag (If-None_Match) test. Returned http status: " << status << endl);
+            DBG(cerr << prolog << "Response Headers: " << endl);
             DBG(copy(resp_h->begin(), resp_h->end(), ostream_iterator<string>(cerr, "\n")));
             DBG(cerr << endl);
             CPPUNIT_ASSERT(status == 304);
+            DBG(cerr << prolog << "ETag test. END " << endl);
 
             // now test a combined etag and time4
             resp_h->clear();
@@ -210,12 +229,12 @@ public:
             CPPUNIT_ASSERT(status == 304);
 
             delete resp_h;
-            resp_h = 0;
+            resp_h = nullptr;
 
         }
         catch (Error & e) {
             delete resp_h;
-            resp_h = 0;
+            resp_h = nullptr;
             CPPUNIT_FAIL(prolog + "Error: " + e.get_error_message());
         }
     }
@@ -223,7 +242,7 @@ public:
     void fetch_url_test_1()
     {
         DBG(cerr << "Entering fetch_url_test 1" << endl);
-        HTTPResponse *stuff = 0;
+        HTTPResponse *stuff = nullptr;
         char c;
         try {
             stuff = http->fetch_url(localhost_url);
@@ -231,17 +250,17 @@ public:
                 fread(&c, 1, 1, stuff->get_stream()) == 1 && !ferror(stuff->get_stream())
                     && !feof(stuff->get_stream()));
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
 
         }
         catch (InternalErr & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an InternalErr from fetch_url: " + e.get_error_message());
         }
         catch (Error & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an Error from fetch_url: " + e.get_error_message());
         }
         // Catch the exception from a failed ASSERT and clean up. Deleting a
@@ -251,7 +270,7 @@ public:
         catch (...) {
             cerr << "Caught unknown exception" << endl;
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             throw;
         }
     }
@@ -259,7 +278,7 @@ public:
     void fetch_url_test_1_cpp()
     {
         DBG(cerr << "Entering fetch_url_test 1" << endl);
-        HTTPResponse *stuff = 0;
+        HTTPResponse *stuff = nullptr;
         http->set_use_cpp_streams(true);
         char c;
         try {
@@ -297,7 +316,7 @@ public:
     void fetch_url_test_2()
     {
         DBG(cerr << "Entering fetch_url_test 2" << endl);
-        HTTPResponse *stuff = 0;
+        HTTPResponse *stuff = nullptr;
         char c;
         try {
             stuff = http->fetch_url(netcdf_das_url);
@@ -309,16 +328,16 @@ public:
                 fread(&c, 1, 1, stuff->get_stream()) == 1 && !ferror(stuff->get_stream())
                     && !feof(stuff->get_stream()));
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
         }
         catch (InternalErr & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an InternalErr from fetch_url: " + e.get_error_message());
         }
         catch (Error & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an Error from fetch_url: " + e.get_error_message());
         }
         // Catch the exception from a failed ASSERT and clean up. Deleting a
@@ -327,7 +346,7 @@ public:
         // entries
         catch (...) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             throw;
         }
     }
@@ -337,7 +356,7 @@ public:
         DBG(cerr << "Entering fetch_url_test 2" << endl);
         http->set_use_cpp_streams(true);
 
-        HTTPResponse *stuff = 0;
+        HTTPResponse *stuff = nullptr;
         char c;
 
         try {
@@ -348,16 +367,16 @@ public:
                 *(stuff->get_cpp_stream()) && !stuff->get_cpp_stream()->bad() && !stuff->get_cpp_stream()->eof());
 
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
         }
         catch (InternalErr & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an InternalErr from fetch_url: " + e.get_error_message());
         }
         catch (Error & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an Error from fetch_url: " + e.get_error_message());
         }
         // Catch the exception from a failed ASSERT and clean up. Deleting a
@@ -366,7 +385,7 @@ public:
         // entries
         catch (...) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             throw;
         }
     }
@@ -374,7 +393,7 @@ public:
     void fetch_url_test_3()
     {
         DBG(cerr << "Entering fetch_url_test 3" << endl);
-        HTTPResponse *stuff = 0;
+        HTTPResponse *stuff = nullptr;
         char c;
         try {
             stuff = http->fetch_url("file:///etc/passwd");
@@ -382,16 +401,16 @@ public:
                 fread(&c, 1, 1, stuff->get_stream()) == 1 && !ferror(stuff->get_stream())
                     && !feof(stuff->get_stream()));
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
         }
         catch (InternalErr & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an InternalErr from fetch_url" + e.get_error_message());
         }
         catch (Error & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an Error from fetch_url: " + e.get_error_message());
         }
         // Catch the exception from a failed ASSERT and clean up. Deleting a
@@ -400,7 +419,7 @@ public:
         // entries
         catch (...) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             throw;
         }
     }
@@ -410,7 +429,7 @@ public:
         DBG(cerr << "Entering fetch_url_test 3" << endl);
         http->set_use_cpp_streams(true);
 
-        HTTPResponse *stuff = 0;
+        HTTPResponse *stuff = nullptr;
         char c;
         try {
             stuff = http->fetch_url("file:///etc/passwd");
@@ -420,16 +439,16 @@ public:
                 *(stuff->get_cpp_stream()) && !stuff->get_cpp_stream()->bad() && !stuff->get_cpp_stream()->eof());
 
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
         }
         catch (InternalErr & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an InternalErr from fetch_url" + e.get_error_message());
         }
         catch (Error & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an Error from fetch_url: " + e.get_error_message());
         }
         // Catch the exception from a failed ASSERT and clean up. Deleting a
@@ -438,7 +457,7 @@ public:
         // entries
         catch (...) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             throw;
         }
     }
@@ -446,7 +465,7 @@ public:
     void fetch_url_test_4()
     {
         DBG(cerr << "Entering fetch_url_test 4" << endl);
-        HTTPResponse *stuff = 0;
+        HTTPResponse *stuff = nullptr;
         char c;
         try {
             string url = (string) "file://" + TEST_SRC_DIR + "/test_config.h";
@@ -455,16 +474,16 @@ public:
                 fread(&c, 1, 1, stuff->get_stream()) == 1 && !ferror(stuff->get_stream())
                     && !feof(stuff->get_stream()));
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
         }
         catch (InternalErr & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an InternalErr from fetch_url" + e.get_error_message());
         }
         catch (Error & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an Error from fetch_url: " + e.get_error_message());
         }
         // Catch the exception from a failed ASSERT and clean up. Deleting a
@@ -473,7 +492,7 @@ public:
         // entries
         catch (...) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             throw;
         }
     }
@@ -483,7 +502,7 @@ public:
         DBG(cerr << "Entering fetch_url_test_4_cpp" << endl);
         http->set_use_cpp_streams(true);
 
-        HTTPResponse *stuff = 0;
+        HTTPResponse *stuff = nullptr;
         char c;
         try {
             string url = (string) "file://" + TEST_SRC_DIR + "/test_config.h";
@@ -494,16 +513,16 @@ public:
                 *(stuff->get_cpp_stream()) && !stuff->get_cpp_stream()->bad() && !stuff->get_cpp_stream()->eof());
 
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
         }
         catch (InternalErr & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an InternalErr from fetch_url" + e.get_error_message());
         }
         catch (Error & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an Error from fetch_url: " + e.get_error_message());
         }
         // Catch the exception from a failed ASSERT and clean up. Deleting a
@@ -512,14 +531,14 @@ public:
         // entries
         catch (...) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             throw;
         }
     }
 
     void get_response_headers_test()
     {
-        HTTPResponse *r = 0;
+        HTTPResponse *r = nullptr;
 
         try {
             r = http->fetch_url(netcdf_das_url);
@@ -536,23 +555,23 @@ public:
             CPPUNIT_ASSERT(find_if(h->begin(), h->end(), REMatch(protocol_header)) != h->end());
 
             delete r;
-            r = 0;
+            r = nullptr;
         }
         catch (InternalErr & e) {
             delete r;
-            r = 0;
+            r = nullptr;
             CPPUNIT_FAIL("Caught an InternalErr exception from get_response_headers: " + e.get_error_message());
         }
         catch (...) {
             delete r;
-            r = 0;
+            r = nullptr;
             throw;
         }
     }
 
     void server_version_test()
     {
-        Response *r = 0;
+        Response *r = nullptr;
         Regex protocol("^[0-9]+\\.[0-9]+$");
         try {
             r = http->fetch_url(netcdf_das_url);
@@ -561,16 +580,16 @@ public:
 
             CPPUNIT_ASSERT(re_match(protocol, r->get_protocol().c_str()));
             delete r;
-            r = 0;
+            r = nullptr;
         }
         catch (InternalErr & e) {
             delete r;
-            r = 0;
+            r = nullptr;
             CPPUNIT_FAIL("Caught an InternalErr exception from server_version: " + e.get_error_message());
         }
         catch (...) {
             delete r;
-            r = 0;
+            r = nullptr;
             throw;
         }
 
@@ -578,17 +597,17 @@ public:
 
     void type_test()
     {
-        Response *r = 0;
+        Response *r = nullptr;
         try {
             r = http->fetch_url(netcdf_das_url);
             DBG(cerr << "r->get_type(): " << r->get_type() << endl);
             CPPUNIT_ASSERT(r->get_type() == dods_das);
             delete r;
-            r = 0;
+            r = nullptr;
         }
         catch (InternalErr & e) {
             delete r;
-            r = 0;
+            r = nullptr;
             CPPUNIT_FAIL("Caught an InternalErr exception from type(): " + e.get_error_message());
         }
 
@@ -605,11 +624,11 @@ public:
                 fread(&c, 1, 1, stuff->get_stream()) == 1 && !ferror(stuff->get_stream())
                     && !feof(stuff->get_stream()));
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
         }
         catch (InternalErr & e) {
             delete stuff;
-            stuff = 0;
+            stuff = nullptr;
             CPPUNIT_FAIL("Caught an InternalErrexception from output: " + e.get_error_message());
         }
     }
@@ -625,7 +644,7 @@ public:
             http->d_http_cache = HTTPCache::instance(http->d_rcr->get_dods_cache_root(), true);
             DBG(cerr << "Instantiate the cache" << endl);
 
-            CPPUNIT_ASSERT(http->d_http_cache != 0);
+            CPPUNIT_ASSERT(http->d_http_cache != nullptr);
             http->d_http_cache->set_cache_enabled(true);
             DBG(cerr << "Enable the cache" << endl);
 
@@ -654,7 +673,7 @@ public:
             http->d_http_cache = HTTPCache::instance(http->d_rcr->get_dods_cache_root(), true);
             DBG(cerr << "Instantiate the cache" << endl);
 
-            CPPUNIT_ASSERT(http->d_http_cache != 0);
+            CPPUNIT_ASSERT(http->d_http_cache != nullptr);
             http->d_http_cache->set_cache_enabled(true);
             DBG(cerr << "Enable the cache" << endl);
 
