@@ -34,22 +34,17 @@
 #include <fstream>
 #include <string>
 
-#include "GetOpt.h"
-
 #include "chunked_ostream.h"
 #include "chunked_istream.h"
 
 #include "InternalErr.h"
+#include "run_tests_cppunit.h"
 #include "test_config.h"
+
 #include "debug.h"
 
-static bool debug = false;
-
 const string path = (string) TEST_SRC_DIR + "/chunked-io";
 
-#undef DBG
-#define DBG(x) do { if (debug) (x); } while(false);
-
 using namespace std;
 using namespace CppUnit;
 using namespace libdap;
@@ -598,46 +593,5 @@ CPPUNIT_TEST_SUITE_REGISTRATION (chunked_iostream_test);
 
 int main(int argc, char *argv[])
 {
-    GetOpt getopt(argc, argv, "dh");
-    int option_char;
-
-    while ((option_char = getopt()) != -1)
-        switch (option_char) {
-        case 'd':
-            debug = 1;  // debug is a static global
-            break;
-
-        case 'h': {     // help - show test names
-            cerr << "Usage: chunked_iostream_test has the following tests:" << endl;
-            const std::vector<Test*> &tests = chunked_iostream_test::suite()->getTests();
-            unsigned int prefix_len = chunked_iostream_test::suite()->getName().append("::").length();
-            for (std::vector<Test*>::const_iterator i = tests.begin(), e = tests.end(); i != e; ++i) {
-                cerr << (*i)->getName().replace(0, prefix_len, "") << endl;
-            }
-            break;
-        }
-
-        default:
-            break;
-        }
-
-    CppUnit::TextTestRunner runner;
-    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
-
-    bool wasSuccessful = true;
-    string test = "";
-    int i = getopt.optind;
-    if (i == argc) {
-        // run them all
-        wasSuccessful = runner.run("");
-    }
-    else {
-        for (; i < argc; ++i) {
-            if (debug) cerr << "Running " << argv[i] << endl;
-            test = chunked_iostream_test::suite()->getName().append("::").append(argv[i]);
-            wasSuccessful = wasSuccessful && runner.run(test);
-        }
-    }
-
-    return wasSuccessful ? 0 : 1;
+    return run_tests<chunked_iostream_test>(argc, argv) ? 0: 1;
 }
