@@ -17,16 +17,18 @@
 #include "DAS.h"
 
 #include "testFile.h"
-#include "GetOpt.h"
+
 #include "InternalErr.h"
 #include "Error.h"
-#include <test_config.h>
+#include "run_tests_cppunit.h"
+#include "test_config.h"
+
 
 using namespace std;
 using namespace libdap;
 using namespace CppUnit;
 
-static bool debug = false;
+
 
 string dprint =
     "\
@@ -233,44 +235,5 @@ CPPUNIT_TEST_SUITE_REGISTRATION (dasT);
 
 int main(int argc, char*argv[])
 {
-    GetOpt getopt(argc, argv, "dh");
-    int option_char;
-
-    while ((option_char = getopt()) != -1)
-	switch (option_char) {
-	case 'd':
-	    debug = true;  // debug is a static global
-	    break;
-	case 'h': {     // help - show test names
-	    cerr << "Usage: dasT has the following tests:" << endl;
-            const std::vector<Test*> &tests = dasT::suite()->getTests();
-            unsigned int prefix_len = dasT::suite()->getName().append("::").length();
-            for (std::vector<Test*>::const_iterator i = tests.begin(), e = tests.end(); i != e; ++i) {
-                cerr << (*i)->getName().replace(0, prefix_len, "") << endl;
-            }
-            break;
-        }
-        default:
-            break;
-        }
-    
-    CppUnit::TextTestRunner runner;
-    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
-    
-    bool wasSuccessful = true;
-    string test = "";
-    int i = getopt.optind;
-    if (i == argc) {
-        // run them all
-        wasSuccessful = runner.run("");
-    }
-    else {
-        for (; i < argc; ++i) {
-            if (debug) cerr << "Running " << argv[i] << endl;
-            test = dasT::suite()->getName().append("::").append(argv[i]);
-            wasSuccessful = wasSuccessful && runner.run(test);
-        }
-    }
-    
-    return wasSuccessful ? 0 : 1;
+    return run_tests<dasT>(argc, argv) ? 0: 1;
 }
