@@ -239,7 +239,7 @@ template<class T> static double *extract_double_array_helper(Array * a)
     int length = a->length();
 
     vector<T> b(length);
-    a->value(&b[0]);    // Extract the values of 'a' to 'b'
+    a->value(b.data());    // Extract the values of 'a' to 'b'
 
     double *dest = new double[length];
     for (int i = 0; i < length; ++i)
@@ -320,7 +320,7 @@ template<class T> static void extract_double_array_helper(Array * a, vector<doub
     int length = a->length();
 
     vector<T> b(length);
-    a->value(&b[0]);    // Extract the values of 'a' to 'b'
+    a->value(b.data());    // Extract the values of 'a' to 'b'
 
     for (int i = 0; i < length; ++i)
         dest[i] = (double) b[i];
@@ -372,7 +372,7 @@ void extract_double_array(Array *a, vector<double> &dest)
     case dods_float32_c:
         return extract_double_array_helper<dods_float32>(a, dest);
     case dods_float64_c:
-        return a->value(&dest[0]);      // no need to copy the values
+        return a->value(dest.data());      // no need to copy the values
         // return extract_double_array_helper<dods_float64>(a, dest);
 
         // Support for DAP4
@@ -525,7 +525,9 @@ libdap_root()
 extern "C" const char *
 libdap_version()
 {
-    return PACKAGE_VERSION;
+    // return PACKAGE_VERSION;
+    // Switched to CVER which is <version>-<build_number>
+    return CVER;
 }
 
 extern "C" const char *
@@ -544,15 +546,16 @@ string systime()
     time_t TimBin;
 
     if (time(&TimBin) == (time_t) -1)
-        return string("time() error");
+        return {"time() error"};
     else {
-        char *ctime_value = ctime(&TimBin);
-        if (ctime_value) {
+        char ctime_value[32];
+        const char *ret = ctime_r(&TimBin, ctime_value);
+        if (ret) {
             string TimStr = ctime_value;
             return TimStr.substr(0, TimStr.size() - 2); // remove the \n
         }
         else
-            return "Unknown";
+            return {"Unknown"};
     }
 }
 
@@ -1128,7 +1131,8 @@ int glob(const char *c, const char *s)
         case '\\':
             /* Force literal match of next char. */
 
-            if (!*c || *s++ != *c++) return i/*1*/;
+            if (!*c || *s != *c) { return i/*1*/; }
+            else { s++; c++; }
             break;
 
         default:
@@ -1170,16 +1174,36 @@ bool pathname_ok(const string &path, bool strict)
 {
     if (path.length() > 255) return false;
 
+#if 0
+    // Make this use a const regex 12/1/21
     Regex name("[-0-9A-z_./]+");
     if (!strict) name = "[:print:]+";
+#endif
 
+    const Regex strict_name("[-0-9A-z_./]+");
+    const Regex relaxed_name("[:print:]+");
+
+#if 0
     string::size_type len = path.length();
-    int result = name.match(path.c_str(), len);
+#endif
+    unsigned long result;
+    if (strict)
+        result = strict_name.match(path);
+    else
+        result = relaxed_name.match(path);
+
+    return (result == path.length());
+
+#if 0
     // Protect against casting too big an uint to int
     // if LEN is bigger than the max int32, the second test can't work
+
+    // This makes no sense - len can never be > 255 given the test at the
+    // start of this function. jhrg 12/1/21
     if (len > INT_MAX || result != static_cast<int>(len)) return false;
 
     return true;
+#endif
 }
 
 //@}
@@ -1214,18 +1238,18 @@ string open_temp_fstream(ofstream &f, const string &name_template, const string
     name.push_back('\0');
 
     // Use mkstemp to make and open the temp file atomically
-    int tmpfile = mkstemps(&name[0], suffix.length());
+    int tmpfile = mkstemps(name.data(), suffix.length());
     if (tmpfile == -1)
         throw Error(internal_error, "Could not make a temporary file.");
     // Open the file using C++ ofstream; get a C++ fstream object
-    f.open(&name[0]);
+    f.open(name.data());
     // Close the file descriptor; the file stays open because of the fstream object
     close(tmpfile);
     // Now test that the fstream object is valid
     if (f.fail())
         throw Error(internal_error, "Could not make a temporary file.");
 
-    return string(&name[0]);
+    return string(name.data());
 }
 
 
